using System;
using UnityEngine;
using System.Collections;
using System.Collections.Generic;
using System.Linq;
using SimpleJSON;
using MVR.FileManagementSecure;

namespace JayJayWon
{
    public class UIASessionBooter : MVRScript
    {
		const string pluginName = "UIASessionBooter";const string pluginAuthor = "JayJayWon"; const string pluginVersion = "1.0";
		public override void Init(){
			try {
				if (containingAtom.name=="CoreControl"){SuperController.LogMessage("UIASessionBooter should not be loaded as a Session Plugin");}
				else {
					Component mainPMC = null;
					foreach (GameObject gameObj in Resources.FindObjectsOfTypeAll<GameObject>().Where(obj => obj.name == "PluginManager")){
						Component comp = gameObj.GetComponent("MVRPluginManager");

						if (comp != null && comp.transform.parent != null){
							if (comp.transform.parent.name == "CoreControl"){
								Component[] components = comp.transform.parent.GetComponentsInChildren<MVRPluginManager>();
								mainPMC = components[0];

								break;
							}
						}
					}
					
					bool isUIAssistLoaded=false;
					if (mainPMC != null){
						MVRPluginManager mvrPM = ((MVRPluginManager)mainPMC);
						JSONClass currentJc = mvrPM.GetJSON(true, true, true);
						JSONClass asObject = currentJc["plugins"].AsObject;
						if ((JSONNode) asObject != (object) null)
						{
						  foreach (string key in asObject.Keys)
						  {
							string pluginVal = currentJc["plugins"][key];
							if (pluginVal.EndsWith("UIAssist.cs")){isUIAssistLoaded=true;break;}

						  }
						}						
						
						if (isUIAssistLoaded){
							
							SuperController.LogMessage("UIAssist is currently loaded as a Session plugin.");
						}
						else{ 
							int pluginID = -1;
							for (int index = 0; index < 1000; ++index){
							if (currentJc["plugins"]["plugin#"+index.ToString()]==null) {
								pluginID = index;
								break;
							  }
							}
							
							string[] varPacakgeFiles = FileManagerSecure.GetFiles("AddonPackages","*.var");
							int highestVarPackageVersion = 0;
							string varPackageName = "";
							foreach (string file in varPacakgeFiles) {
								
								if (file.StartsWith("AddonPackages\\JayJayWon.UIAssist(Patron)")){
									string fileWithoutVAR = file.Substring(0,file.Length-4);
									int index = fileWithoutVAR.LastIndexOf('.');
									int varPackageVersion = int.Parse(fileWithoutVAR.Substring(index+1));
									if (varPackageVersion>highestVarPackageVersion){
										highestVarPackageVersion=varPackageVersion;
										varPackageName="JayJayWon.UIAssist(Patron)."+highestVarPackageVersion.ToString()+":/Custom/Scripts/JayJayWon/UIAssist.cs";
									}
								}
							}
							if (varPackageName!="" && pluginID!=-1){
								currentJc["plugins"]["plugin#"+pluginID.ToString()]=varPackageName;
								mvrPM.LateRestoreFromJSON(currentJc);
							}
							
						}
					}
				}
				
				JSONStorableString message = new JSONStorableString("message","Attach this plugin to any Atom in the scene file 'Saves\\scene\\default.json' and then save the scene.\n\nThis will ensure UIAssist is loaded as a Session plugin every time VAM is started.");
				UIDynamicTextField messageTextField = CreateTextField(message,false);
				messageTextField.height = 500;
				
				
				string pluginDetails =pluginDetails = pluginName +" v"+pluginVersion + "\nby "+pluginAuthor;
				JSONStorableString pluginVersionJSON = new JSONStorableString("pluginVersion",pluginDetails);
				UIDynamicTextField pluginVersionTextField = CreateTextField(pluginVersionJSON,false);
				pluginVersionTextField.height = 1;

			}catch (Exception e) {SuperController.LogError("Exception caught: " + e);}
		}
	
	}
	
}